parse_cli_string

Function parse_cli_string 

fn parse_cli_string(command_string: String) -> Result<CliAction, String>
Parses a raw command string into a structured [CliAction]. See ‘../help.txt’ for a list of available commands.

Arguments

  • command_string - The raw string to parse

Errors

Returns an error string if the command is unknown, arguments are missing, or the argument count/types are invalid.