parse_universe_and_channel

Function parse_universe_and_channel 

fn parse_universe_and_channel(
    args: SplitAsciiWhitespace<'_>,
) -> Result<(usize, ChannelIndex), String>
Parses a universe and channel pair formatted as [universe].[channel] into a tuple.

Arguments

  • args - Iterator over the remaining whitespace-separated arguments

Errors

Returns an error string if the format is missing a dot or if the numbers are out of valid bounds.