run_command

Function run_command 

pub fn run_command(is_kernel: bool, command: String) -> (LogLevel, String)
Runs a command string by parsing it into a [CliAction] and executing it.

Arguments

  • is_kernel - Flag indicating whether the command is executed from the kernel console
  • command - The raw command string entered by the user