pub fn run_command(is_kernel: bool, command: String) -> (LogLevel, String)Expand description
Runs a command string by parsing it into a [CliAction] and executing it.
Arguments
is_kernel- Flag indicating whether the command is executed from the kernel consolecommand- The raw command string entered by the user